==> chanjet-navigator-0.0.9.tgz: package/src/page/Page.js <==
/**
 * Created with WebStorm.
 * User: gp
 * Date: 16-2-2
 */

import React, { Component } from 'react';
import ReactDOM from 'react-dom';
import NavBar from './NavigateBar';
import getTheme from './styles/page'
//import support from 'chanjet-env-check';
import {config} from '../config'


/**
 * 通常一个web应用只有一个html页面,我们在这里约定一个术语'Page'来描述能承载一屏内容的一个javascript容器组件，
 * 相对于多页面的一个html页面，而不是一个真正的html类型的页面。
 * Page本身也是一个React Component，component的生命周期只改变了render()，其它的未做任何修改，可正常使用。
 * @extends React.Component
 * @example
 * import React, { Component } from 'react';
 * import Page from 'chanjet-ui/lib/Page';
 *
 * class CustomerDetail extends Page{
 *      //页面标题
 *      title = '客户详情';
 *
 *      //顶部状态栏配置, 没有特殊需求可以不用配置
 *      navBar = {
 *          right:{
 *              type:'button',
 *              item:{
 *                  icon:'add',
 *                  onClick: function(){}
 *              }
 *          }
 *      };
 *
 *      //渲染页面，注意是renderPage
 *      renderContent(){
 *          return(
 *              <div>
 *                  detail
 *              </div>
 *          )
 *      }
 * }
 *
 * export default CustomerDetail;
 *
 */
class Page extends Component {

    constructor(props, context) {
        super(props, context);

        /**
         *@member navigationController {NavigationController} 应用导航控制器，Application级别，单例
         *@memberOf Page.prototype
         * @example
         *  this.navigationController.push('/detail');
         */
        this.navigationController = props.navigationController||{};

        /**
         *@member navbarInstance {NavigateBar} 导航栏实例，可以用此实例调用其下的公开方法
         *@memberOf Page.prototype
         * @example
         *  this.navbarInstance.setTitle('新标题')
         *  this.navbarInstance.setRightMeun({})
         */
        //this.navbarInstance

        /**
         * 页面标题，纯文本，默认会对html标签编码。
         * @type {String}
         */
        this.title = '';

        /**
         * 顶部导航栏配置
         * @type {JSONObject}
         * @typeof navBar
         * @property [onBackClick] {Function} 导航栏左侧返回按钮事件
         * @property [onCloseClick] {Function} 导航栏左侧关闭按钮事件
         * @property [backgroundColor] {String} 导航栏背景颜色
         * @property [color] {String} 字体颜色, (icon是字体icon, 通过颜色控制)
         * @property [highlightColor] {String} 按钮激活时字体颜色
         * @property [disabledColor] {String} 按钮禁用时的字体颜色
         *
         * @property [right] {JSONObject} 导航栏右侧配置,可放置一个按钮或菜单, 不可共存,  按钮只能是一个图标或者是一个文本,不能是图标加文本
         *      @property [right.hide=false] {Boolean} 是否隐藏右侧内容
         *      @propery right.type {String} 右侧内容区放置的组件类型, menu, button
         *      @property right.item {Object/Array} 按钮或菜单配置, menu传入的是菜单项的配置的列表<Array>
         *          @property right.item.text {String} <b>按钮或菜单项</b>文本, 当类型是button时,优先取text,如果text和icon同时传会忽略掉icon
         *          @property right.item.onClick {Function} <b>按钮或菜单项</b>点击事件,
         *          @property right.item.icon {String} <b>按钮</b>icon, 类型有: add , back , edit , share , del , openLink
         *          @property [right.item.disabled=false] {Boolean} <b>按钮</b>是否禁用
         *
         * @example
         *   navBar = {
         *          onBackClick: function(){},
         *          onCloseClick: function(){},
         *          right:
         *              {
         *                  type:'menu',
         *                  item :[
         *                      {text:"item1", onClick:()=>alert('item1')},
         *                      {text:"item2", onClick:()=>alert('item2')}
         *                  ]
         *              }
         *          color: '#ffffff',
         *          highlightColor:'#ffffff',
         *          disabledColor: '#ffffff'
         *  }
         */
        this.navBar = {};

        this.pageId = props.pageId;
        this.isRootPage = props.isRootPage;

        /**
         * page容器上添加一个自定义的class
         * @type {string}
         */
        this.className = '';
        
        let SavedInstanceState = this._getSavedInstanceState();
        if(SavedInstanceState != null){
            this.restoreInstanceState(SavedInstanceState);
        }

        this.env = this._getEvn();

        this.init();
        
        window.page = this;
    }

    render() {
        let pageContentEls = this.renderContent();
        !this.navBar?this.navBar = {}:'';
        this.navBar.title = this.title;
        this.navBar = this.postNavbarMixin(this.navBar||{});
        var navbar = this.navBar;

        let navbarCfg = config.theme.page.navbar;
        if(!navbar.backgroundColor){navbar.backgroundColor=navbarCfg.backgroundColor}
        if(!navbar.color){navbar.color=navbarCfg.color}
        if(!navbar.highlightColor){navbar.highlightColor=navbarCfg.highlightColor}
        if(!navbar.disabledColor){navbar.disabledColor=navbarCfg.disabledColor}

        if(!navbar.title){navbar.title=navbarCfg.titleText}


        let navOptions = {
            navOpt:navbar,
            scope: this
        }



        const env = this.env;
        let theme = this._processTheme(env);

        let nav = (<NavBar ref="navbarInstance" config={navOptions}  env={env}/>);

        return (
            < div className="page-container" style={theme.page}>
                {nav}
                <div className={this.className+' page-content'} style={theme.pageContent} > {pageContentEls} </div>
            </ div >
        )
    }


    /**
     *  初始化方法，会在render之前调用
     */
    init(){return null;}

    /**
     * 在navBar配置在传递使用之前调用, 通常用来在使用navBar之前对其进行修改
     * @param navbarOpt {JSONObject} Page中的navBar配置
     * @returns {JSONObject}
     *
     * @example
     * postNavbarMixin(navbarOpt){
     *   navbarOpt.right.item.icon = 'del';
     *   return navbarOpt
     * }
     *
     */
    postNavbarMixin(navbarOpt){
        return navbarOpt
    }

    /**
     * 当页面上一个页面返回的时候会执行此方法
     * @param behiverCode {String} 值为 'ok'和'cancel' 表示用户做了确认或取消操作
     * @param data  {JSONObject} 回传的参数
     * @param requestCode 当前页面访问
     */
    pageBackReceiveResult(behiverCode,data, requestCode){return null;}

    /**
     * 页面激活时调用
     */
    active(){
        if(this.navbarInstance){
            this.navbarInstance.active()
        }
    }

    /**
     * Page页面内容渲染
     * @returns {ReactXML}
     */
    renderContent() {
      return (<div></div>);
    }

    /**
     * native销毁页面时,通知App控制器调用，用户重写此方法，在方法内给savedInstanceState赋值
     * @param savedInstanceState=null {JSONObject} 要存贮的状态数据
     * @return {JSONObject}
     */
    saveInstanceState(savedInstanceState=null){
       return savedInstanceState;
    }

    /**
     * native已销毁的页面恢复时通知App控制器调用，savedState是从native中获取
     * 当这个方法被调用时savedState必然不为空
     * @param savedState=null {JSONObject} native传过来要回复的状态数据
     * @returns {JSONObject}
     */
    restoreInstanceState(savedState=null){
        return savedState;
    }

    setNavbarInstance(navbarInstance){
        this.navbarInstance = navbarInstance;
    }

    //navBar中配置的onClick事件,供在native中按钮点击时调用
    //@param uri {String} onBackClick , onCloseClick, right/item/onClick  right/item/0/onClick   'function(a){alert(a)}'
    executeNativeClick(uri){
        if(this.navbarInstance){
            this.navbarInstance.executeNativeClick(uri);
        }
    }

    /**
     * 关闭 native 轻应用
     */
    close(){
        if(this.env === 'chanjet'){
            cordova.exec(
                function(info) {},
                function(error) {},
                'Destroy',
                'destroy',
                []
            )
        }
    }

    //android按返回物理键盘时会调用此方法
    androidBackAction(){
        if(this.navbarInstance){
            this.navbarInstance.back();
        }
    }


    /**
     * 从native中获取已保存的状态数据
     * @private
     */
    _getSavedInstanceState(){
       return null;
    }

    _getEvn(){
        if(window.mutants && window.mutants.env && window.mutants.env.platform){
            return window.mutants.env.platform;
        }
        return;
    }

    _processTheme(env){
        var theme = getTheme();
        if(env != 'browser'){
           theme.pageContent.paddingTop = 0;
        }
        return theme;
    }



}

export default Page;

==> chanjet-navigator-2.1.1.tgz: package/src/page/Page.js <==
/**
 * Created with WebStorm.
 * User: gp
 * Date: 16-2-2
 */

import React, { Component } from 'react';
import ReactDOM from 'react-dom';
import NavBar from './NavigateBar';
import getTheme from './styles/page'
//import support from 'chanjet-env-check';
import {config} from '../config'


/**
 * 通常一个web应用只有一个html页面,我们在这里约定一个术语'Page'来描述能承载一屏内容的一个javascript容器组件，
 * 相对于多页面的一个html页面，而不是一个真正的html类型的页面。
 * Page本身也是一个React Component，component的生命周期只改变了render()，其它的未做任何修改，可正常使用。
 * @extends React.Component
 * @example
 * import React, { Component } from 'react';
 * import Page from 'chanjet-ui/lib/Page';
 *
 * class CustomerDetail extends Page{
 *      //页面标题
 *      title = '客户详情';
 *
 *      //顶部状态栏配置, 没有特殊需求可以不用配置
 *      navBar = {
 *          right:{
 *              type:'button',
 *              item:{
 *                  icon:'add',
 *                  onClick: function(){}
 *              }
 *          }
 *      };
 *
 *      //渲染页面，注意是renderPage
 *      renderContent(){
 *          return(
 *              <div>
 *                  detail
 *              </div>
 *          )
 *      }
 * }
 *
 * export default CustomerDetail;
 *
 */
class Page extends Component {

    constructor(props, context) {
        super(props, context);

        /**
         *@member navigationController {NavigationController} 应用导航控制器，Application级别，单例
         *@memberOf Page.prototype
         * @example
         *  this.navigationController.push('/detail');
         */
        this.navigationController = props.navigationController||{};

        /**
         *@member navbarInstance {NavigateBar} 导航栏实例，可以用此实例调用其下的公开方法
         *@memberOf Page.prototype
         * @example
         *  this.navbarInstance.setTitle('新标题')
         *  this.navbarInstance.setRightMeun({})
         */
        //this.navbarInstance

        /**
         * 页面标题，纯文本，默认会对html标签编码。
         * @type {String}
         */
        this.title = '';

        /**
         * 当前页是否处于激活状态
         * @type {boolean}
         */
        this.isActive = false;

        /**
         * 顶部导航栏配置
         * @type {JSONObject}
         * @typeof navBar
         * @property [onBackClick] {Function} 导航栏左侧返回按钮事件
         * @property [onCloseClick] {Function} 导航栏左侧关闭按钮事件
         * @property [backgroundColor] {String} 导航栏背景颜色
         * @property [color] {String} 字体颜色, (icon是字体icon, 通过颜色控制)
         * @property [highlightColor] {String} 按钮激活时字体颜色
         * @property [disabledColor] {String} 按钮禁用时的字体颜色
         *
         * @property [right] {JSONObject} 导航栏右侧配置,可放置一个按钮或菜单, 不可共存,  按钮只能是一个图标或者是一个文本,不能是图标加文本
         *      @property [right.hide=false] {Boolean} 是否隐藏右侧内容
         *      @propery right.type {String} 右侧内容区放置的组件类型, menu, button
         *      @property right.
         *      @property right.item {Object/Array} 按钮或菜单配置, menu传入的是菜单项的配置的列表<Array>
         *          @property right.item.text {String} <b>按钮或菜单项</b>文本, 当类型是button时,优先取text,如果text和icon同时传会忽略掉icon
         *          @property right.item.onClick {Function} <b>按钮或菜单项</b>点击事件,
         *          @property right.item.icon {String} <b>按钮</b>icon, 类型有: add , back , edit , share , del , openLink
         *          @property [right.item.disabled=false] {Boolean} <b>按钮</b>是否禁用
         *
         * @example
         *   navBar = {
         *          onBackClick: function(){},
         *          onCloseClick: function(){},
         *          right:
         *              {
         *                  type:'menu',
         *                  item :[
         *                      {text:"item1", onClick:()=>alert('item1')},
         *                      {text:"item2", onClick:()=>alert('item2')}
         *                  ]
         *              }
         *          color: '#ffffff',
         *          highlightColor:'#ffffff',
         *          disabledColor: '#ffffff'
         *  }
         */
        this.navBar = {};

        /**
         * 当前page的id
         * @type {any}
         */
        this.pageId = props.pageId;

        /**
         * 当前的page是否是进入应用的第一页
         * @type {any}
         */
        this.isRootPage = props.isRootPage;

        /**
         * page容器上添加一个自定义的class
         * @type {string}
         */
        this.className = '';
        
        let SavedInstanceState = this._getSavedInstanceState();
        if(SavedInstanceState != null){
            this.restoreInstanceState(SavedInstanceState);
        }

        this.env = this._getEvn();

        this.init();
        
        window.page = this;
    }

    render() {
        let pageContentEls = this.renderContent();
        !this.navBar?this.navBar = {}:'';
        this.navBar.title = this.title;
        this.navBar = this.postNavbarMixin(this.navBar||{});
        var navbar = this.navBar;

        let navbarCfg = config.theme.page.navbar;
        if(!navbar.backgroundColor){navbar.backgroundColor=navbarCfg.backgroundColor}
        if(!navbar.color){navbar.color=navbarCfg.color}
        if(!navbar.highlightColor){navbar.highlightColor=navbarCfg.highlightColor}
        if(!navbar.disabledColor){navbar.disabledColor=navbarCfg.disabledColor}

        if(!navbar.title){navbar.title=navbarCfg.titleText}


        let navOptions = {
            navOpt:navbar,
            scope: this
        }



        const env = this.env;
        let theme = this._processTheme(env);

        let nav = (<NavBar ref="navbarInstance" config={navOptions}  env={env}/>);

        return (
            < div className="page-container" style={theme.page}>
                {nav}
                <div className={this.className+' page-content'} style={theme.pageContent} > {pageContentEls} </div>
            </ div >
        )
    }


    /**
     *  初始化方法，会在render之前调用
     */
    init(){return null;}

    /**
     * 在navBar配置在传递使用之前调用, 通常用来在使用navBar之前对其进行修改
     * @param navbarOpt {JSONObject} Page中的navBar配置
     * @returns {JSONObject}
     *
     * @example
     * postNavbarMixin(navbarOpt){
     *   navbarOpt.right.item.icon = 'del';
     *   return navbarOpt
     * }
     *
     */
    postNavbarMixin(navbarOpt){
        return navbarOpt
    }

    /**
     * 当页面上一个页面返回的时候会执行此方法
     * @param behiverCode {String} 值为 'ok'和'cancel' 表示用户做了确认或取消操作
     * @param data  {JSONObject} 回传的参数
     * @param requestCode 当前页面访问
     */
    pageBackReceiveResult(behiverCode,data, requestCode){return null;}

    /**
     * @private
     */
    willActive(){
        this.isActive = true;
        if(this.navbarInstance){
            this.navbarInstance.active()
        }
        this.active();
    }

    /**
     * 页面激活时调用
     */
    active(){

    }

    /**
     * @private
     */
    willUnActive(){
        this.isActive = false;
        let pageNode = ReactDOM.findDOMNode(this);
        let nodes = pageNode.querySelectorAll('input[type=text], div[contenteditable=true], textarea');
        let len = nodes.length;
        for(let i=0; i<len; i++){
            nodes[i].blur();
        }
        this.unActive();
    }

    /**
     *
     */
    unActive(){

    }

    /**
     * Page页面内容渲染
     * @returns {ReactXML}
     */
    renderContent() {
      return (<div></div>);
    }

    /**
     * native销毁页面时,通知App控制器调用，用户重写此方法，在方法内给savedInstanceState赋值
     * @param savedInstanceState=null {JSONObject} 要存贮的状态数据
     * @return {JSONObject}
     */
    saveInstanceState(savedInstanceState=null){
       return savedInstanceState;
    }

    /**
     * native已销毁的页面恢复时通知App控制器调用，savedState是从native中获取
     * 当这个方法被调用时savedState必然不为空
     * @param savedState=null {JSONObject} native传过来要回复的状态数据
     * @returns {JSONObject}
     */
    restoreInstanceState(savedState=null){
        return savedState;
    }

    setNavbarInstance(navbarInstance){
        this.navbarInstance = navbarInstance;
    }

    //navBar中配置的onClick事件,供在native中按钮点击时调用
    //@param uri {String} onBackClick , onCloseClick, right/item/onClick  right/item/0/onClick   'function(a){alert(a)}'
    executeNativeClick(uri){
        if(this.navbarInstance){
            this.navbarInstance.executeNativeClick(uri);
        }
    }

    /**
     * 关闭 native 轻应用
     */
    close(){
        if(this.env === 'chanjet'){
            cordova.exec(
                function(info) {},
                function(error) {},
                'Destroy',
                'destroy',
                []
            )
        }
    }

    //android按返回物理键盘时会调用此方法
    androidBackAction(){
        if(this.navbarInstance){
            this.navbarInstance.back();
        }
    }


    /**
     * 从props.state中获取已保存的状态数据
     * @private
     */
    _getSavedInstanceState(){
        return this.props.state ? this.props.state : null;
    }

    _getEvn(){
        if(window.mutants && window.mutants.env && window.mutants.env.platform){
            return window.mutants.env.platform;
        }
        return;
    }

    _processTheme(env){
        var theme = getTheme();
        if(env != 'browser'){
           theme.page.paddingTop = 0;
        }
        return theme;
    }



}

export default Page;
